@@ -554,7 +554,10 @@ class AgentLifeCycle:
                             print('{:{terminal_size}.{terminal_size}}'.format(
                                 status, terminal_size=terminal_size), end="\r", flush=True)
                         else:
-                            print('{:{trm_sz}.{trm_sz}}'.format(status, trm_sz=80), end="\r", flush=True)
+                            print('{:{trm_sz}.{trm_sz}}'.format(
+                                status, trm_sz=80), end="\r", flush=True)
+                print("[" + str(i) + "/" + str(N) + "] " + image_name_short +
+                      " - " + bcolors.OKBLUE + "OK" + bcolors.ENDC + "\033[K")
             except docker.errors.ImageNotFound:
                 print("[" + str(i) + "/" + str(N) + "] " + image_name_short +
                       " - " + bcolors.FAIL + "FAILED" + bcolors.ENDC + "\033[K")
